@@ -11,7 +11,7 @@ class JobOffer(Model):
     title = models.CharField(max_length=255)
     description = models.TextField()
     skills = models.ManyToManyField(Skill)
-    creationDate = models.DateField(auto_now_add=True)
+    creationDate = models.DateTimeField(auto_now_add=True)
     closingDate = models.DateField()
     conversation = models.ManyToManyField(Conversation, blank=True)
 
